# Example of enumerate:
# printing polynomials,
# calculating values of polynomials


def poly_val(coeffs, x):
    """Calculate value of polynomial at a point

    coeffs: a list of non-negative integer coefficients of a polynomial
            sorted from lowest degree to highest degree
    x: a float, the point at which to evaluate the polynomial
    """

    sum = 0
    for i, coe in enumerate(coeffs):
        sum += coe * x ** i
    return sum


def poly_string(coeffs):
    """Give a string representation of a polynomial

    coeffs: a list of non-negative integer coefficients of a polynomial
            sorted from lowest degree to highest degree
    """
    terms = []

    if coeffs:  # Adding the constant term
        coe = coeffs[0]
        if coe != 0:
            terms.append(str(coe))
        coeffs = coeffs[1:]

    if coeffs:  # Adding the linear term
        coe = coeffs[0]
        if coe == 1:
            terms.append("x")
        elif coe > 1:
            terms.append(f"{coe}x")
        coeffs = coeffs[1:]

    if coeffs:  # Adding all other terms
        for i, coe in enumerate(coeffs):
            if coe == 1:
                terms.append(f"x^{i+2}")
            elif coe > 1:
                terms.append(f"{coe}x^{i+2}")

    if not terms:  # If we were given an empty list or only zeros
        return "0"
    else:
        terms.reverse()
        return " + ".join(terms)


# Give a list of coefficients sorted from highest to lowest degree
# (as in exercise 1, week 4).
coeffs = [6, 12, 0, 1, 5]  # 6x^4 + 12x^3 + x + 5
x = 2

coeffs.reverse()


print(f"The value of {poly_string(coeffs)} at {x = } is {poly_val(coeffs, x)}.")
